Merge branch 'master' into bloom
[adu.git] / adu.h
diff --git a/adu.h b/adu.h
index 1e6519bc91c12fb6a03307042de9c56f97c1c92b..5e99709c3679571b70ccaf5db5bc70c62957eb83 100644 (file)
--- a/adu.h
+++ b/adu.h
@@ -4,11 +4,11 @@
  * Licensed under the GPL v2. For licencing details see COPYING.
  */
 
/** \file para.h global paraslash definitions */
 
 #include <sys/stat.h>
 #include <fcntl.h>
-#include <sys/wait.h>
+#include <signal.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <time.h> /* time(), localtime() */
 #include <errno.h>
 #include <limits.h>
 #include <stdarg.h>
-#include <ctype.h>
-#include <netinet/in.h>
-#include <arpa/inet.h>
-#include <sys/socket.h>
-#include <sys/un.h> /* needed by create_pf_socket */
+#include <inttypes.h>
 #include <string.h>
 #include <assert.h>
 #include <osl.h>
 #include "gcc-compat.h"
-
-/** compute the minimum of \a a and \a b */
-#define MIN(a,b) ((a) < (b) ? (a) : (b))
-/** compute the maximum of \a a and \a b */
-#define MAX(a,b) ((a) > (b) ? (a) : (b))
-/** compute the absolute value of \a a */
-#define ABS(a) ((a) > 0 ? (a) : -(a))
+#include "portable_io.h"
 
 /** debug loglevel, gets really noisy */
 #define DEBUG 1
@@ -94,7 +84,6 @@
 #define EMERG_LOG(...)
 #endif
 /** \endcond */
-__printf_2_3 void __log(int, const char*, ...);
 
 /**
  * Write a log message to a dynamically allocated string.
@@ -107,7 +96,7 @@ __printf_2_3 void __log(int, const char*, ...);
 { \
        int n; \
        size_t size = 100; \
-       p = para_malloc(size); \
+       p = adu_malloc(size); \
        while (1) { \
                va_list ap; \
                /* Try to print in the allocated space. */ \
@@ -122,6 +111,94 @@ __printf_2_3 void __log(int, const char*, ...);
                        size = n + 1; /* precisely what is needed */ \
                else /* glibc 2.0 */ \
                        size *= 2; /* twice the old size */ \
-               p = para_realloc(p, size); \
+               p = adu_realloc(p, size); \
        } \
 }
+
+/** Evaluates to 1 if x < y, to -1 if x > y and to 0 if x == y. */
+#define NUM_COMPARE(x, y) ((int)((x) < (y)) - (int)((x) > (y)))
+
+/** The columns of the directory table. */
+enum dir_table_columns {
+       /** The name of the directory. */
+       DT_NAME,
+       /** The dir count number. */
+       DT_NUM,
+       /** The number of the parent directory. */
+       DT_PARENT_NUM,
+       /** The number of bytes of all regular files. */
+       DT_BYTES,
+       /** The number of all regular files. */
+       DT_FILES,
+       /** Number of columns in this table. */
+       NUM_DT_COLUMNS
+};
+
+extern struct osl_table *dir_table;
+
+/** The adu command line options. */
+extern struct gengetopt_args_info conf;
+
+/**
+ * The select command line options.
+ *
+ * Either given at the command line, or via the \a set command
+ * in interactive mode.
+ */
+extern struct select_args_info select_conf;
+
+/**
+ * Compare two osl objects pointing to unsigned integers of 64 bit size.
+ *
+ * \param obj1 Pointer to the first integer.
+ * \param obj2 Pointer to the second integer.
+ *
+ * \return The values required for an osl compare function.
+ *
+ * \sa osl_compare_func, osl_hash_compare().
+ */
+_static_inline_ int uint64_compare(const struct osl_object *obj1,
+               const struct osl_object *obj2)
+{
+       uint64_t d1 = read_u64((const char *)obj1->data);
+       uint64_t d2 = read_u64((const char *)obj2->data);
+
+       if (d1 < d2)
+               return 1;
+       if (d1 > d2)
+               return -1;
+       return 0;
+}
+
+/**
+ * Compare the size of two directories
+ *
+ * \param obj1 Pointer to the first object.
+ * \param obj2 Pointer to the second object.
+ *
+ * This function first compares the size values as usual integers. If they compare as
+ * equal, the address of \a obj1 and \a obj2 are compared. So this compare function
+ * returns zero if and only if \a obj1 and \a obj2 point to the same memory area.
+ */
+_static_inline_ int size_compare(const struct osl_object *obj1, const struct osl_object *obj2)
+{
+       uint64_t d1 = *(uint64_t *)obj1->data;
+       uint64_t d2 = *(uint64_t *)obj2->data;
+       int ret = NUM_COMPARE(d2, d1);
+
+       if (ret)
+               return ret;
+       //INFO_LOG("addresses: %p, %p\n", obj1->data, obj2->data);
+       return NUM_COMPARE(obj2->data, obj1->data);
+}
+
+/* adu.c */
+__printf_2_3 void __log(int, const char*, ...);
+int open_dir_table(int create);
+void check_signals(void);
+/* create.c */
+int com_create(void);
+
+/* interactive.c */
+void print_interactive_help(void);
+int com_interactive(void);
@@ -4,11 +4,11 @@
  */
 
-/** \file para.h global paraslash definitions */
+/** \file adu.h \brief Global definitions. */
 
 #include <sys/stat.h>